{% comment %}

  The normal list, spiced up.
  This is included via comments/list.html

  The id="comments-..." is required for JavaScript,
  the 'comments/comment.html template is also used by the Ajax view.

{% endcomment %}
<div id="comments-{{ target_object_id }}" data-object-id="{{ target_object_id }}" class="comments {% if not comment_list %} empty{% endif %}">
  {% for comment in comment_list %}{% include "comments/comment.html" %}{% endfor %}
</div>
